import baseLexicon from 'htsl-uikit-lexicon';
import Component from 'htsl-component';

/*
* @Author: Gilles Coomans
*/

var foundation = baseLexicon.createDialect('foundation');

foundation.colorLabels = ['primary', 'secondary', 'success', 'alert', 'warning'];

/*
 * @Author: Gilles Coomans
 * Foundation 6 button api for htsl
 */
foundation.addCompounds(function (h) {
	return {
		iconButton: function iconButton(icon, content) {
			return this.button(h.class('icon-button').faicon(icon), content);
		},

		// basical button
		simpleButton: function simpleButton(content, type, templ) {
			return this.button(h.class(type, !!type).class('button'), content, templ);
		},

		// hollow button (mean just-border style)
		hollowButton: function hollowButton(content, type, templ) {
			return this.button(h.class(type, !!type).classes('button hollow'), content, templ);
		},

		// anchor button
		aButton: function aButton(href, content, type, templ) {
			return this.a(href, h.class(type, !!type).class('button'), content, templ);
		},
		aHollowButton: function aHollowButton(href, content, type, templ) {
			return this.a(href, h.class(type, !!type).classes('button hollow'), content, templ);
		},

		// close button : for closing action : templ = h.data('close') || h.click(...)
		closeButton: function closeButton(templ) {
			return this.button(h.class('close-button').attr('aria-label', 'Close alert').attr('type', 'button').span(h.attr('aria-hidden', 'true'), '\xD7'), templ);
		},
		buttonGroup: function buttonGroup(buttons) {
			return this.div(h.class('button-group'), buttons);
		},
		smallButtonGroup: function smallButtonGroup(buttons) {
			return this.div(h.classes('small button-group'), buttons);
		},
		switchButton: function switchButton(name, text) {
			return this.div(h.class('switch').input('checkbox', '', h.id(name).class('show-for-sr').attr('name', name)).label(h.class('switch-paddle').attr('for', name).span(h.class('show-for-sr').text(text))));
		}
	};
}).addCompounds(function () {
	var coloredAPI = {};
	foundation.colorLabels.forEach(function (color) {
		// BUTTONS
		coloredAPI[color + 'Button'] = function (content, templ) {
			return this.simpleButton(content, color, templ);
		};
		coloredAPI[color + 'AButton'] = function (href, content, templ) {
			return this.aButton(href, content, color, templ);
		};
		coloredAPI[color + 'AHollowButton'] = function (href, content, templ) {
			return this.aHollowButton(href, content, color, templ);
		};
		coloredAPI[color + 'HollowButton'] = function (content, templ) {
			return this.hollowButton(content, color, templ);
		};
	});
	return coloredAPI;
});

/*
 * @Author: Gilles Coomans
 * @Date:   2017-03-22 15:11:25
 * @Last Modified by:   Gilles Coomans
 * @Last Modified time: 2017-03-22 16:31:19
 */
/* global Foundation, $ */

foundation.addCompounds(function (h) {
	return {
		multiLevelAccordionMenu: function multiLevelAccordionMenu(children) {
			return this.div(h.class('multi-level-accordion-menu').ul(h.class('accordion-menu').data('accordionMenu', true).class('vertical'), children, h.onDom(function (node) {
				new Foundation.AccordionMenu($(node), {});
			})));
		},
		multiLevelAccordionSubMenu: function multiLevelAccordionSubMenu(name, depth, children) {
			return this.li(h.a('#', name).ul(h.class('menu').class('vertical').class('sublevel-' + depth), children));
		},
		multiLevelAccordionMenuLeaf: function multiLevelAccordionMenuLeaf(href, content) {
			return this.li(h.a(href, h.class('subitem'), content));
		},
		testAccordionMenu: function testAccordionMenu() {
			return this.multiLevelAccordionMenu(h.multiLevelAccordionMenuLeaf('#', 'hello root 1').multiLevelAccordionSubMenu('Item 1', 1, h.multiLevelAccordionMenuLeaf('#', 'hello world').multiLevelAccordionSubMenu('Item 1.2', 2, h.multiLevelAccordionMenuLeaf('#', 'hello world 1').multiLevelAccordionMenuLeaf('#', 'hello world 2').multiLevelAccordionMenuLeaf('#', 'hello world 3'))).multiLevelAccordionSubMenu('Item 2', 1, h.multiLevelAccordionMenuLeaf('#', 'hello bloupi').multiLevelAccordionMenuLeaf('#', 'hello bloupi 2').multiLevelAccordionSubMenu('Item 2.2', 2, h.multiLevelAccordionMenuLeaf('#', 'hello foo 1').multiLevelAccordionMenuLeaf('#', 'hello foo 2').multiLevelAccordionMenuLeaf('#', 'hello foo 3'))));
		}
	};
});

/*
 * @Author: Gilles Coomans
 */
/* global Foundation, $ */

foundation.addCompounds(function (h) {
	return {
		dropDownMenu: function dropDownMenu(items) {
			return this.ul(h.class('dropdown').class('menu').data('dropdownMenu').each(items, function (item) {
				return this.li(item);
			}));
		},
		dropDownPane: function dropDownPane(content) {
			return this.div(h.class('dropdown-pane').data('dropdown').data('autoFocus', true).onDom(function (node) {
				setTimeout(function () {
					new Foundation.Dropdown($(node), {});
				});
			}), content);
		}
	};
});

/*
 * @Author: Gilles Coomans
 * @Date:   2017-03-22 15:09:40
 * @Last Modified by:   Gilles Coomans
 * @Last Modified time: 2017-03-22 16:31:12
 */
foundation.addCompounds(function (h) {
	return {
		/********************************
   ****************** FORM ********
   ********************************/

		radioSwitch: function radioSwitch(groupName, text) {
			return this.div(h.class('switch').input('radio', '', h.id(name).attr('name', groupName)).label(h.class('switch-paddle').attr('for', name).span(h.class('show-for-sr'), text)));
		},
		fieldSet: function fieldSet(legend, content) {
			return this.tag('fieldset', [h.class('fieldset').tag('legend', legend), content]);
		},
		helpText: function helpText(targetId, text) {
			return this.p(h.class('help-text').attr('id', targetId), text);
		},
		radio: function radio(opt) {
			opt.id = opt.id || opt.name + opt.value;
			return this.input('radio', opt.value, h.attr('name', opt.name).attr('id', opt.id).if(opt.required, h.attr('required', ''))).label(h.attr('for', opt.id), opt.text || opt.value);
		},

		// checkbox: function(id, value, text) {
		// 	return this.input('checkbox', value, h.attr('id', id))
		// 		.label(h.attr('for', id), text);
		// },
		inlineLabelInputRow: function inlineLabelInputRow(opt) {
			return this.div(h.class('row').div(h.class('small-3').class('columns').label(h.class('text-right').class('middle').attr('for', opt.id), opt.label)).div(h.class('small-9').class('columns').input('text', opt.value, h.attr('id', opt.id).if(opt.placeholder, h.attr('placeholder', opt.placeholder)))));
		},
		inputField: function inputField(opts) {
			return this.div(h.class('input-field').if(opts.icon, h.label(h.attr('for', opts.id).icon(opts.icon))).input(opts.type || 'text', typeof opts.val !== 'undefined' ? opts.val : '{{ ' + opts.path + ' }}', h.attr('id', opts.id).attr('placeholder', opts.placeholder).attr('required', opts.required).if(opts.icon, h.class('labeled'))).div(h.visible('{{ $error.' + opts.path + ' }}').class('formfield-error').text('{{ $error.' + opts.path + '.detail }}')));
		},

		/**
   * an input-group with coloredLabel-input-button
   * @param  {Object} opt { label:String|Template, value:*, required:Bool(false by def), placeholder:String, buttonText:String|Template }
   * @return {Template}     chainable
   */
		inlineColoredLabelInputButton: function inlineColoredLabelInputButton(opt) {
			return this.div(h.class('input-group').span(h.class('input-group-label'), opt.label).input(opt.type || 'text', opt.value || '', h.class('input-group-field').id(opt.id).if(opt.required, h.prop('required', true)).if(opt.placeholder, h.attr('placeholder', opt.placeholder))).div(
			// warning : foundation 6.2.4 button height issue that has been corrected in develop branch for the moment
			// see : https://github.com/zurb/foundation-sites/pull/9308/files
			h.class('input-group-button').primaryButton(opt.buttonText || 'Submit')));
		},
		inlineColoredLabelInput: function inlineColoredLabelInput(opt) {
			return this.div(h.class('input-group').span(h.class('input-group-label'), opt.label).input(opt.type || 'text', opt.value || '', h.class('input-group-field').id(opt.id).if(opt.required, h.prop('required', true)).if(opt.placeholder, h.attr('placeholder', opt.placeholder))));
		},
		fileUploadButton: function fileUploadButton(id, text, handler) {
			return this.label(h.class('button').attr('for', id), text).input('file', '', h.class('show-for-sr').attr('name', 'photo').id(id).on('change', handler));
		}
	};
});

/*
 * @Author: Gilles Coomans
 */

/**
 * Abstract Component for full screen panel with background
 * @abstract
 */
var OverlayPanel = Component.extends(Component, {
	render: function render(firstLevel) {
		var h = foundation.initializer(firstLevel);
		return h.overlayPanel(this.props.opt, this.content(firstLevel), this);
	}
});

/**
 * Full screen Confirm Panel Component with background
 */
var ConfirmPanel = Component.extends(OverlayPanel, {
	validate: function validate(e) {
		e.preventDefault();
		this.unmount();
		this.state.callback(true);
	},
	cancel: function cancel(e) {
		e.preventDefault();
		this.unmount();
		this.state.callback(false);
	},
	content: function content(firstLevel) {
		var h = foundation.initializer(firstLevel);
		return h.class('confirm-panel').warningDialog(h.h3(this.state.title).p(this.state.message).div(h.class('dialog-buttons-container').warningButton(h.click(this.validate), '\u2713').alertButton(h.click(this.cancel), '\xD7')));
	}
});

/**
 * Full screen Alert Panel Component with background
 */
var AlertPanel = Component.extends(OverlayPanel, {
	content: function content(firstLevel) {
		var h = foundation.initializer(firstLevel);
		return h.class('alert-panel').alertDialog(h.h3(this.state.title).p(this.state.message).div(h.class('dialog-buttons-container').alertButton(h.click(this.unmount), '\u2713')), h.click(this.unmount));
	}
});

/**
 * Full screen Modal Component with background
 */
var UikitModal = Component.extends(OverlayPanel, {
	content: function content(firstLevel) {
		var h = foundation.initializer(firstLevel);
		return h.class('uik-modal').div(h.class('modal-panel').div(h.class('modal-panel-content'), typeof this.props.content === 'function' ? this.props.content(this.state, this.props, this) : this.props.content).closeButton(h.click(this.unmount)));
	}
});

/**
 * Side Panel Component with background
 * opt: {
 * 		side: 'left' || 'right',
 * 		width: '100px', 
 * 		height: '100px' 
 * }
 */
var SidePanel = Component.extends(OverlayPanel, {
	content: function content(firstLevel) {
		var h = foundation.initializer(firstLevel),
		    opt = this.props.opt;
		return h.div(h.class('side-panel').class('side-panel--' + opt.side).div(h.class('side-panel-content').if(opt.side === 'left' || opt.side === 'right', h.style('width', opt.width), h.style('height', opt.height)), typeof this.props.content === 'function' ? this.props.content(this.state, this.props, this) : this.props.content).closeButton(h.click(this.unmount)));
	}
});

/**
 ******************* LEXEMS
 */
foundation.addCompounds(function (h) {
	return {
		/**
   * overlay panel. if opt.closeOnBackgroundClick : needs that ctrl implements unmount method
   * @param  {[type]} opt  [description]
   * @param  {[type]} ctrl [description]
   * @return {[type]}      [description]
   */
		overlayPanel: function overlayPanel(opt, content, ctrl) {
			return h.div(h.class('overlay-panel').if(opt.panelClass, h.class(opt.panelClass)).if(!opt.noBackground, h.overlayPanelBackground(opt.closeOnBackgroundClick, ctrl)), content);
		},
		overlayPanelBackground: function overlayPanelBackground(closeOnBackgroundClick, ctrl) {
			return this.div(h.class('overlay-panel-background').if(closeOnBackgroundClick, h.click(function (e) {
				if (e.target === e.currentTarget) ctrl.unmount();
			})));
		},

		/***********************************
   *********** DIALOGS PANEL *********
   ***********************************/
		postalConfirmPanel: function postalConfirmPanel(channel) {
			return this.postalComponent(channel, ConfirmPanel, { opt: {} });
		},
		postalAlertPanel: function postalAlertPanel(channel) {
			return this.postalComponent(channel, AlertPanel, {
				opt: {
					closeOnBackgroundClick: true
				}
			});
		},
		postalUikitModal: function postalUikitModal(channel, opt, content) {
			return this.postalComponent(channel, UikitModal, { content: content, opt: opt });
		},
		postalSidePanel: function postalSidePanel(channel, opt, content) {
			return this.postalComponent(channel, SidePanel, { opt: opt, content: content });
		}
	};
});

/*
 * @Author: Gilles Coomans
 * @Date:   2017-03-22 15:22:44
 * @Last Modified by:   Gilles Coomans
 * @Last Modified time: 2017-03-22 19:31:31
 */

foundation.addCompounds(function (h) {
	return {
		backgroundImage: function backgroundImage(url, backgroundSize) {
			backgroundSize = backgroundSize || 'cover';
			return this.style('background', 'url(' + url + ') no-repeat center center').style('backgroundSize', backgroundSize);
		},
		thumbnail: function thumbnail(src, alt, templ) {
			return this.img(src, h.class('thumbnail').attr('alt', alt || 'image with no alternate text'), templ);
		},
		roundedThumbnail: function roundedThumbnail(src, alt, templ) {
			return this.img(src, h.classes('thumbnail rounded').attr('alt', alt || 'image with no alternate text'), templ);
		}
	};
});

foundation.addCompounds(function (h) {
	return {
		callout: function callout(type, content, templ) {
			return this.div(h.class('callout').class(type), content, templ);
		},
		closableCallout: function closableCallout(type, content, templ) {
			return this.container(function (ctrl) {
				return h.callout(type, content, h.closeButton(h.click(ctrl.unmount))._use(templ));
			});
		},
		dialog: function dialog(type, content, templ) {
			return this.div(h.class('dialog').class(type), content, templ);
		},
		closableDialog: function closableDialog(type, content, templ) {
			return this.container(function (ctrl) {
				return h.dialog(type, content, h.closeButton(h.click(ctrl.unmount))._use(templ));
			});
		}
	};
}).addCompounds(function () {
	var coloredAPI = {};
	foundation.colorLabels.forEach(function (color) {

		var upCaseColor = color[0].toUpperCase() + color.substring(1);

		// DIALOGS AND CALLOUTS
		coloredAPI[color + 'Dialog'] = function (content, templ) {
			return this.dialog(color, content, templ);
		};
		coloredAPI[color + 'Callout'] = function (content, templ) {
			return this.callout(color, content, templ);
		};
		coloredAPI['closable' + upCaseColor + 'Dialog'] = function (content, templ) {
			return this.closableDialog(color, content, templ);
		};
		coloredAPI['closable' + upCaseColor + 'Callout'] = function (content, templ) {
			return this.closableCallout(color, content, templ);
		};
	});
	return coloredAPI;
});

/**
 * Foundation 6 api for htsl
 */
/* global Foundation, $ */
var index = foundation.addCompounds(function (h) {
	return {
		/**
   * MISC
   */
		faicon: function faicon(type, templ) {
			return this.i(h.class('fa').class('fa-' + type), templ);
		},
		icon: function icon(type) {
			return this.i(h.class('fi-' + type));
		},
		badge: function badge(text, type) {
			return this.span(h.class('badge').if(type, h.class(type)), text);
		},
		coloredLabel: function coloredLabel(text, type) {
			return this.span(h.class('label').if(type, h.class(type)), text);
		},


		/**
   * HELPERS
   */

		tooltip: function tooltip(title, text, opt) {
			opt = opt || {};
			return this.span(h.class('has-tip').if(opt.top, h.class('top')).data('tooltip').if(opt.noClickOpen, h.data('clickOpen', false)).attr('aria-haspopup', true).data('disableHover', false).attr('tabindex', '1').attr('title', title).onDom(function (node) {
				new Foundation.Tooltip($(node), {}); // eslint-disable-line no-undef
			}), text);
		},

		// breadcrumb: function(label, elements) {
		// 	return this
		// 		.nav(h.attr('aria-label', label)
		// 			.attr('role', 'navigation')
		// 			.ul(
		// 				h.class('breadcrumbs')
		// 				.li(h.a('#', 'Home'))
		// 				.li(h.a('#', 'Features'))
		// 				.li(h.class('disabled'), 'Gene Splicing')
		// 				.li(
		// 					h.span(h.class('show-for-sr'), 'Current: '),
		// 					' Cloning'
		// 				)
		// 			)
		// 		);
		// },


		/**
   * NAV
   */

		// subNav: function(title, label) {
		// 	return this.ul(
		// 		h.class("sub-nav")
		// 		.class("menu")
		// 		.attr("role", "navigation")
		// 		// label title
		// 		.attr("title", label)
		// 		// title
		// 		.li(h.class("sub-nav-title"), title)
		// 		// children
		// 		.li(
		// 			h.class("active")
		// 			.span(
		// 				h.class("show-for-sr"),
		// 				"You're viewing "
		// 			)
		// 			.a(h.prop("href"), "All")
		// 		)
		// 		.li(h.a(h.attr("href", "#"), "Active"))
		// 		.li(h.a(h.attr("href", "#"), "Pending"))
		// 		.li(h.a(h.attr("href", "#"), "Suspended"))
		// 	);
		// },


		/***********************************
   *************** CARDS *************
   ***********************************/

		productCard: function productCard(title, price, imgSrc, details) {
			return this.div(h.class('product-card').class('item-wrapper').div(h.class('img-wrapper').a('#', h.class('button').class('expand').class('add-to-cart'), 'Add to Cart').a('#', h.img(imgSrc))).a('#', h.h3(title)).h5(price).p(details));
		},


		/***********************************
   *************** CONTAINERS ********
   ***********************************/
		topBar: function topBar(contentLeft, contentRight) {
			return this.div(h.class('top-bar').div(h.class('top-bar-left'), contentLeft).div(h.class('top-bar-right'), contentRight));
		},
		offCanvas: function offCanvas(leftMenuContent, content, rightMenuContent) {
			return this.div(h.class('off-canvas-wrapper').div(h.class('off-canvas-wrapper-inner').data('offCanvasWrapper').if(leftMenuContent, h.div(h.class('off-canvas').class('position-left').attr('id', 'offCanvas').data('offCanvas', true).closeButton(h.data('close')), leftMenuContent)).div(h.class('off-canvas').class('position-right').attr('id', 'offCanvasRight').data('offCanvas', true).data('position', 'right'), content).if(rightMenuContent, h.div(h.class('off-canvas-content').data('offCanvasContent', true).closeButton(h.data('close')), rightMenuContent))));
		}
	};
}).addCompounds(function () {
	var coloredAPI = {};
	foundation.colorLabels.forEach(function (color) {
		coloredAPI[color + 'Badge'] = function (text) {
			return this.badge(text, color);
		};
		coloredAPI[color + 'Label'] = function (text) {
			return this.coloredLabel(text, color);
		};
	});
	return coloredAPI;
});

export default index;
//# sourceMappingURL=index.mjs.map
