'use strict';

var _htslComponent = require('htsl-component');

var _htslComponent2 = _interopRequireDefault(_htslComponent);

var _lexicon = require('./lexicon');

var _lexicon2 = _interopRequireDefault(_lexicon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Abstract Component for full screen panel with background
 * @abstract
 */
/*
 * @Author: Gilles Coomans
 */

var OverlayPanel = _htslComponent2.default.extends(_htslComponent2.default, {
	render: function render(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel);
		return h.overlayPanel(this.props.opt, this.content(firstLevel), this);
	}
});

/**
 * Full screen Confirm Panel Component with background
 */
var ConfirmPanel = _htslComponent2.default.extends(OverlayPanel, {
	validate: function validate(e) {
		e.preventDefault();
		this.unmount();
		this.state.callback(true);
	},
	cancel: function cancel(e) {
		e.preventDefault();
		this.unmount();
		this.state.callback(false);
	},
	content: function content(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel);
		return h.class('confirm-panel').warningDialog(h.h3(this.state.title).p(this.state.message).div(h.class('dialog-buttons-container').warningButton(h.click(this.validate), '\u2713').alertButton(h.click(this.cancel), '\xD7')));
	}
});

/**
 * Full screen Alert Panel Component with background
 */
var AlertPanel = _htslComponent2.default.extends(OverlayPanel, {
	content: function content(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel);
		return h.class('alert-panel').alertDialog(h.h3(this.state.title).p(this.state.message).div(h.class('dialog-buttons-container').alertButton(h.click(this.unmount), '\u2713')), h.click(this.unmount));
	}
});

/**
 * Full screen Modal Component with background
 */
var UikitModal = _htslComponent2.default.extends(OverlayPanel, {
	content: function content(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel);
		return h.class('uik-modal').div(h.class('modal-panel').div(h.class('modal-panel-content'), typeof this.props.content === 'function' ? this.props.content(this.state, this.props, this) : this.props.content).closeButton(h.click(this.unmount)));
	}
});

/**
 * Side Panel Component with background
 * opt: {
 * 		side: 'left' || 'right',
 * 		width: '100px', 
 * 		height: '100px' 
 * }
 */
var SidePanel = _htslComponent2.default.extends(OverlayPanel, {
	content: function content(firstLevel) {
		var h = _lexicon2.default.initializer(firstLevel),
		    opt = this.props.opt;
		return h.div(h.class('side-panel').class('side-panel--' + opt.side).div(h.class('side-panel-content').if(opt.side === 'left' || opt.side === 'right', h.style('width', opt.width), h.style('height', opt.height)), typeof this.props.content === 'function' ? this.props.content(this.state, this.props, this) : this.props.content).closeButton(h.click(this.unmount)));
	}
});

/**
 ******************* LEXEMS
 */
_lexicon2.default.addCompounds(function (h) {
	return {
		/**
   * overlay panel. if opt.closeOnBackgroundClick : needs that ctrl implements unmount method
   * @param  {[type]} opt  [description]
   * @param  {[type]} ctrl [description]
   * @return {[type]}      [description]
   */
		overlayPanel: function overlayPanel(opt, content, ctrl) {
			return h.div(h.class('overlay-panel').if(opt.panelClass, h.class(opt.panelClass)).if(!opt.noBackground, h.overlayPanelBackground(opt.closeOnBackgroundClick, ctrl)), content);
		},
		overlayPanelBackground: function overlayPanelBackground(closeOnBackgroundClick, ctrl) {
			return this.div(h.class('overlay-panel-background').if(closeOnBackgroundClick, h.click(function (e) {
				if (e.target === e.currentTarget) ctrl.unmount();
			})));
		},

		/***********************************
   *********** DIALOGS PANEL *********
   ***********************************/
		postalConfirmPanel: function postalConfirmPanel(channel) {
			return this.postalComponent(channel, ConfirmPanel, { opt: {} });
		},
		postalAlertPanel: function postalAlertPanel(channel) {
			return this.postalComponent(channel, AlertPanel, {
				opt: {
					closeOnBackgroundClick: true
				}
			});
		},
		postalUikitModal: function postalUikitModal(channel, opt, content) {
			return this.postalComponent(channel, UikitModal, { content: content, opt: opt });
		},
		postalSidePanel: function postalSidePanel(channel, opt, content) {
			return this.postalComponent(channel, SidePanel, { opt: opt, content: content });
		}
	};
});